@@ -195,7 +195,6 @@ class BayesNet(object):
         # Precompute ELBO
         for node in self.nodes["Y"].getNodes(): node.TauTrick = False # important to do this for ELBO computation
         elbo = self.calculateELBO()
-        # for node in self.nodes["Y"].getNodes(): node.TauTrick = self.options["Y_ELBO_TauTrick"]
         for node in self.nodes["Y"].getNodes(): node.TauTrick = True
 
         if self.options['verbose']:
@@ -267,7 +266,7 @@ class BayesNet(object):
                         print('- Time spent in ELBO computation: %.1f%%' % (100*t_elbo/(t_updates+t_elbo)) )
 
                     # Assess convergence
-                    if i>self.options["start_elbo"] and not self.options['forceiter']:
+                    if i>self.options["start_elbo"] and i>self.options["min_iter"] and not self.options['forceiter']:
                         convergence_token, converged = self.assess_convergence(delta_elbo, elbo.iloc[0]["total"], convergence_token)
                         if converged:
                             number_factors = number_factors[:i]
@@ -281,7 +280,7 @@ class BayesNet(object):
 
                 # Print other statistics
                 if self.options['verbose']:
-                    self.print_verbose_message()
+                    self.print_verbose_message(i)
 
 
                 iter_time[i] = time()-t
@@ -307,7 +306,7 @@ class BayesNet(object):
                 # self.train_stats['length_scales'] = self.lscales
                 # self.train_stats['scales'] = self.scales
 
-    def print_verbose_message(self):
+    def print_verbose_message(self, i):
         """Method to print training statistics if Verbose is TRUE"""
 
         # Memory usage (does not work in Windows)
@@ -337,6 +336,13 @@ class BayesNet(object):
         tau = self.nodes["Tau"].getExpectation()
         print("- Tau per view (average):  " + "   ".join([ "View %s: %.2f" % (m,tau[m].mean()) for m in range(self.dim["M"])]))
 
+        #Sigma:
+        if 'Sigma' in self.nodes.keys():
+            sigma = self.nodes["Sigma"]
+            if i >= sigma.start_opt and i % sigma.opt_freq == 0:
+                print('Sigma node has been optimised:\n- Lengthscales = %s \n- Scale = %s' % \
+                (np.array2string(sigma.get_ls(), precision=2, separator=", "), np.array2string(1-sigma.get_zeta(), precision=2, separator=", ")))
+
         print("\n")
 
     def assess_convergence(self, delta_elbo, first_elbo, convergence_token):
@@ -348,11 +354,11 @@ class BayesNet(object):
 
         # Assess convergence based on the fraction of deltaELBO change
         if self.options["convergence_mode"] == "fast":
-            convergence_threshold = 0.0001
+            convergence_threshold = 0.0005
         elif self.options["convergence_mode"] == "medium":
-            convergence_threshold = 0.00001
+            convergence_threshold = 0.00005
         elif self.options["convergence_mode"] == "slow":
-            convergence_threshold = 0.000001
+            convergence_threshold = 0.000005
         else:
             print("Convergence mode not recognised"); exit()
 
@@ -568,7 +574,7 @@ class StochasticBayesNet(BayesNet):
                 print("- Step size: %.3f" % ro )
 
             if self.options['verbose']:
-                self.print_verbose_message()
+                self.print_verbose_message(i)
             # print("")
 
             iter_time[i] = time()-t
