@@ -199,7 +199,10 @@ class Sigma_Node_base(Node):
         """
         Method to fetch ELBO-optimal length-scales
         """
-        ls = self.Kc.get_ls()
+        if hasattr(self, 'Kc') and self.Kc is not None:
+            ls = self.Kc.get_ls()
+        else:
+            ls = np.array([np.nan] * self.K)
         return ls
 
     def get_x(self):
@@ -209,6 +212,11 @@ class Sigma_Node_base(Node):
         x = self.Kg.get_x()
         return x
 
+    def get_sharedness(self):
+        Kgs = self.Kg.Kmat
+        sharedness = np.array([np.tril(np.abs((Kgs[k,:,:] - np.eye(self.G)))).sum()/(self.G * (self.G -1)/2) for k in range(self.K)])
+        return sharedness
+
     def get_sigma(self):
         """
         Method to get sigma hyperparameter
@@ -527,8 +535,8 @@ class Sigma_Node_base(Node):
             self.zeta[k] = best_zeta
 
         self.calc_sigma_terms(only_inverse=False)
-        print('Sigma node has been optimised:\n- Lengthscales = %s \n- Scale = %s' % \
-            (np.array2string(self.get_ls(), precision=2, separator=", "), np.array2string(1-self.get_zeta(), precision=2, separator=", ")))
+        # print('Sigma node has been optimised:\n- Lengthscales = %s \n- Scale = %s' % \
+        #     (np.array2string(self.get_ls(), precision=2, separator=", "), np.array2string(1-self.get_zeta(), precision=2, separator=", ")))
 
     def updateParameters(self, ix, ro):
         """
@@ -671,6 +679,7 @@ class Sigma_Node_warping(Sigma_Node_base):
         super().__init__(dim, sample_cov, groups, start_opt, opt_freq, n_grid, rankx, model_groups)
 
         self.kronecker = False
+        self.new_alignment = False
 
         # set warping options
         self.G4warping = len(self.groups) # number of groups to consider for warping (if no group kernel this differs from self.G)
@@ -696,6 +705,7 @@ class Sigma_Node_warping(Sigma_Node_base):
         # covariate kernel is initialized after first warping
         self.Kc = None
 
+
     def updateParameters(self, ix, ro):
         """
         Public method to update the nodes parameters
@@ -705,11 +715,18 @@ class Sigma_Node_warping(Sigma_Node_base):
             ZE = self.markov_blanket['Z'].getExpectation()
             self.align_sample_cov_dtw(ZE)
             print("Covariates were aligned between groups.")
+            self.new_alignment = True
 
         if self.iter >= self.start_opt and self.iter % self.opt_freq == 0:
             var = self.markov_blanket['Z']
             self.optimise(var)
 
+            # after a new alignment check that a sufficient smoothness and sharedness is present for a sensible alignment
+            if self.new_alignment and (all(1-self.get_zeta() < 0.3) or all(self.get_sharedness()< 0.3)):
+                print("WARNING: Factors show little shared smooth variation between groups - alignment might not work as intended.")
+                #self.sample_cov_transformed = copy.copy(self.sample_cov)
+                self.new_alignment = False
+
 
     def align_sample_cov_dtw(self, Z):
         """
